@@ -1,6 +1,6 @@
 package Map::Tube::Exception;
 
-$Map::Tube::Exception::VERSION   = '3.01';
+$Map::Tube::Exception::VERSION   = '3.02';
 $Map::Tube::Exception::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube::Exception - Base exception package as Moo Role for Map::Tube::* famil
 
 =head1 VERSION
 
-Version 3.01
+Version 3.02
 
 =cut
 
@@ -38,7 +38,10 @@ sub as_string {
 
 =head1 DESCRIPTION
 
-Base exception package as Moo Role for Map::Tube::* family..
+Base exception package as Moo Role for Map::Tube::* family.
+
+Extracted out of the  distribution  Map::Tube v3.0, so that it can be shared with
+Map::Tube and it's Map::Tube::* family. It has been re-structured in the process.
 
 =head1 STATUS CODES
 
@@ -61,6 +64,9 @@ Base exception package as Moo Role for Map::Tube::* family..
     |     113     | Found multi lined station.                                  |
     |     114     | Found unsupported map.                                      |
     |     115     | Missing supported map.                                      |
+    |     116     | Found unsupported object.                                   |
+    |     117     | Missing supported object, Map::Tube::Node / Map::Tube::Line |
+    |     118     | Invalid supported object.                                   |
     +-------------+-------------------------------------------------------------+
 
 =head1 AUTHOR
